﻿import json

with open('elevesNSI.json', 'r') as read_json_data:
    elevesNSI = json.load(read_json_data)

with open('structure_base_simplifiee.json', 'r') as read_json_modele:
    modele = json.load(read_json_modele)

# Création d'un serveur Web
from flask import Flask, jsonify
app = Flask(__name__)
app.config['JSON_SORT_KEYS'] = False

@app.route('/')
def index():
    return jsonify({'Message': 'Bienvenue sur le serveur Web API de la NSI'})

# Gérer les messages d'erreur
from flask import make_response
@app.errorhandler(404)
def not_found(error):
    return make_response(jsonify({'error': 'Not found'}), 404)

# 1er service : afficher la liste des élèves
@app.route('/api/eleves', methods=['GET'])
def info_eleves():
    return jsonify(elevesNSI)

# 2ond service : Récupérer la structure de base
@app.route('/api/modele', methods=['GET'])
def recup_modele():
    return jsonify(modele)

# 3eme service : afficher les infos pour 1 élève
from flask import abort
@app.route('/api/eleve/<string:nom>', methods=['GET'])
def info_eleve(nom):
    res = [eleve for eleve in elevesNSI["eleves"] if eleve["nom"]==nom]
    if len(res) == 0:
        abort(404)
    return jsonify(res)

# 4eme service : ajouter un élève à la liste
from flask import request
@app.route('/api/add', methods=['POST'])
def ajout_eleve():
    if not request.json:
        abort(400)
    elevesNSI["eleves"].append(request.json)
    elevesNSI["nombre"]=len(elevesNSI["eleves"])
    with open('elevesNSI.json', 'w') as write_json_data:
        json.dump(elevesNSI, write_json_data)
    return jsonify(elevesNSI)

# 5eme service : supprimer un eleve
@app.route('/api/delete/<string:nom>', methods=['DELETE'])
def suppression_eleve(nom):
    elevesNSI["eleves"] = [eleve for eleve in elevesNSI["eleves"] if eleve["nom"] != nom]
    elevesNSI["nombre"]=len(elevesNSI["eleves"])
    with open('elevesNSI.json', 'w') as write_json_data:
        json.dump(elevesNSI, write_json_data)
    return jsonify(elevesNSI)

# 6eme service : obtenir un dico listant les réseaux sociaux
import re
regexRS= { "D(.)*MO(.)*" : "Dailymotion",
           "D(.)*Z(.)*" : "Deezer",
           "D(.)*(C|K|QU)(.)*D(.)*" : "Discord",
           "F(.)*B(.)*(C|K|QU)(.)*" : "Facebook",
           "FL(.)*(C|K|QU)(.)*" : "Flickr",
           "I(.)*T(.)*G(.)*" : "Instagram",
           "L(.)*(C|K|QU)(.)*D(.)*" : "Linkedin",
           "M(.)*S(.)*G(.)*" : "Messenger",
           "P(.)*R(.)*S(.)*P(.)*" : "Periscope",
           "P(.)*T(.)*R(.)*" : "Pinterest",
           "R(.)*D(.)*" : "Reddit",
           "S(.)*CH(.)*" : "Snapchat",
           "S(.)*(C|K|QU)(.)*" : "SoundCloud",
           "SP(.)*T(.)*F(.)*" : "Spotify",
           "T(.)*(C|K|QU)(.)*T(.)*(C|K|QU)(.)*" : "Tiktok",
           "(TW|TOU)(.)*CH(.)*" : "Twitch",
           "(TW|TOU)(.)*T(.)*R(.)*" : "Twitter",
           "V(.)*M(.)*" : "Vimeo",
           "W(.)*A(.)*P(.)*" : "WhatsApp",
           "Y(.)*T(.)*B(.)*" : "Youtube",
           "(.)*" : "???"}
def quelRS(rs):
    for key, value in regexRS.items():
        if (re.match(key, rs.upper())!=None):
            return value
@app.route('/api/getRS', methods=['GET'])
def reseaux_sociaux():
    baseActuelle=[rs["reseaux-sociaux"] for rs in elevesNSI["eleves"]]
    res={"NBreponses":0,"RS":{}}
    res["NBreponses"]=len(baseActuelle)
    for liste in baseActuelle:
        if (liste!={}):
            for element in liste:
                rs=quelRS(element)
                if (rs not in res["RS"]):
                    res["RS"][rs]=1
                else:
                    res["RS"][rs]=res["RS"][rs]+1
    return jsonify(res)

# 7eme service : liste des élèves poursuivant la NSI
@app.route('/api/poursuiteNSI', methods=['GET'])
def poursuite_NSI():
    res={"nombre":0,"eleves":[]}
    for eleve in elevesNSI["eleves"]:
        if (eleve["poursuite-NSI"] == True):
            ajout={"nom": eleve["nom"],"prenom":eleve["prenom"]}
            res["eleves"].append(ajout)

    res["nombre"]=len(res["eleves"])
    return jsonify(res)


if __name__ == '__main__':
    app.run(debug=True)

